@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: zlib
-version: 0.5.3.1
-id: zlib-0.5.3.1-a78f28b72a90bc6d93acffb0c82dfef3
+version: 0.5.4.0
+id: zlib-0.5.4.0-0d818ac207ea095f2439042e85ca4d8f
 
 license: BSD3
-copyright: (c) 2006-2008 Duncan Coutts
+copyright: (c) 2006-2012 Duncan Coutts
 maintainer: Duncan Coutts <duncan@community.haskell.org>
 stability:
 homepage:
 package-url:
+synopsis: Compression and decompression in the gzip and zlib formats
 description: This package provides a pure interface for compressing and
              decompressing streams of data represented as lazy
              '\''ByteString'\''s. It uses the zlib C library so it has high
@@ -25,20 +26,21 @@ exposed: True
 exposed-modules: Codec.Compression.GZip Codec.Compression.Zlib
                  Codec.Compression.Zlib.Raw Codec.Compression.Zlib.Internal
 hidden-modules: Codec.Compression.Zlib.Stream
-import-dirs: /usr/local/lib/ghc/zlib-0.5.3.1
-library-dirs: /usr/local/lib/ghc/zlib-0.5.3.1
-hs-libraries: HSzlib-0.5.3.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/zlib-0.5.4.0
+library-dirs: /usr/local/lib/ghc/zlib-0.5.4.0
+hs-libraries: HSzlib-0.5.4.0
 extra-libraries: z
 extra-ghci-libraries:
 include-dirs:
 includes: zlib.h
-depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
+depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-zlib-0.5.3.1/html/zlib.haddock
-haddock-html: /usr/local/share/doc/hs-zlib-0.5.3.1/html
+haddock-interfaces: /usr/local/share/doc/hs-zlib-0.5.4.0/html/zlib.haddock
+haddock-html: /usr/local/share/doc/hs-zlib-0.5.4.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
